#3D Scanning and printing

This week I made some 3d printed tools and 3d scanned using photogrammetry.

### Page Summary
0. Introduction
1. Testing Design rules
2. Designing for 3D printing
3. 3D models
4. Creating toolpaths
5. Printing
6. References
7. Photogrammetry
8. 3D Scanning
9. Design files
---

0. Introduction
---
3D printing is an additive form of manufacturing. It has a lot of advantages and disadvantages, by my understanding throughout this week, I have listed some below. Like Neil says, 3D printers are to FabLabs, what microwaves are to kitchens. They can do some parts but not replace all of manufacturing.  

First advantage is that waste is minimised, because you use only the material that is required in the final product.  
It is ideal for rapid prototyping, as it can make complex geometries that you traditionally need more than one processes to make. It is good for custom and small-scale mass customization production processes, but not necessarily for mass manufacturing. It also doesn't have the best accuracy and tolerances, so not ideal for applications where precision is important. But it is fast, user-friendly and therefore very accessible.  

The most widely used technology for 3D printing is Fusion Deposition Modelling (FDM). I will use FDM printers this week. There is also SLA, Stereolithography and Powder Bed Printing 3DP.  

This [hubs.com knowledge base](https://www.hubs.com/knowledge-base/additive-manufacturing-process/) has very good information about the subject. Also this [BCN local documentation](https://fablabbcn-projects.gitlab.io/learning/fabacademy-local-docs/material/week05/).   

1. Testing Design rules
---
I used [these files on thingiverse](https://www.thingiverse.com/thing:533472) to test design rules of the Ultimaker 3 I used in the lab.   
These test geometries are designed to evaluate specific performance characteristics and motion systems in common low-cost FDM/FFF machines. Make Magazine's third annual 3D Printing Shootout was conducted using these files, created by Andreas Bastian to benchmark performance of desktop 3D printers.  

These tests individually help with testing:
1. Dimensional Accuracy  
2. Bridging Performance  
3. Overhang Performance  
4. Negative Space Tolerance  
5. Fine Positive Features Performance  
6. XY Resonance  
7. Z Resonance  

I use [Cura](https://ultimaker.com/software/ultimaker-cura) to make the gcode. The tests are supposed to be evaluated at default 'normal' settings in PLA with a 0.4mm nozzle.  
Layer Height: 0.15   
Infill: 18%   
Adhesion: On  
Support: Off  

After downloading the files, I sliced them one by one like so:  
![cura](./images/3dpd/curag.jpg)  

I used an Ultimaker 2+ to print the prints in FabLab SP.  
![U2](./images/3dpd/u2.jpg)   

There is a nice evaluation system described in [How to evaluate the test geometries](https://makezine.com/2014/11/07/how-to-evaluate-the-2015-make-3dp-test-probes/). It assigns a score by observing details to evaluate the different qualities of the machine. I think it is an interesting way to determine and learn how to design well for a particular machine. I used this to score the printer I was using. This is the result.
![evaluation](./images/3dpd/eval.jpg)  

Here are all the tests overall:
![tests](./images/3dpd/tests.jpg)  

It means that if I keep overhand till 50 deg, negative Tolerance atleast 0.4mm, not keep too fine details the qulaity of the design printing should be fine.  

2. Designing for 3D printing
---
I wanted to make simple tools this weeks, so I experimented with simple joint mechanisms. Some references that I used to develop my designs:

- [Compliant Mechanisms Research (CMR by BYU)](<https://www.compliantmechanisms.byu.edu/maker-resources>)
- [Why machines that bend are better](<https://www.youtube.com/watch?v=97t7Xj_iBv0>)
- [Compliant mechanisms by Devin Montes](<https://www.myminifactory.com/users/MakeAnything/collection/compliant-mechanisms>) \- [video](<https://www.youtube.com/watch?v=PgDJlLqeTdo>)
- [These transformed chopsticks](<https://www.myminifactory.com/object/3d-print-96658>)

I first made a scaled-up version of a simple Gemclip and some other simple geometry clips. I bent one end to add a dimension, that does not allow it to be made using only one subtractive method.

![simpleclips](<./images/3dpd/simpleclips.jpg>)

I first made it in 2D in plan to the size and proportion I wanted, and then extruded it in Z. Later I bent the inner part so that the model could be made subtractively easily, as now it had an undercut.

![side](<./images/3dpd/side.jpg>)

Then I used some parts of these tranformed chopsticks reference above that I found

![transformedchopsticks](<./images/3dpd/transformedchopsticks.jpg>)

And then made normal tweezers and then modified the geomtry to make it compliant like the chopsticks above.

![designing](<./images/3dpd/designing.jpg>)

3. 3D models
---
<div class="sketchfab-embed-wrapper">
<iframe title="A 3D model" width="600" height="450" src="https://sketchfab.com/models/acabba4a8e95408484dcc6343d08ade7/embed?autospin=0.2" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
<p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
</div>

Next after, watching some videos on making compliant mechanisms, I made a simple pick-and-place plier to test out the bending.  

<div class="sketchfab-embed-wrapper">
<iframe title="A 3D model" width="600" height="450" src="https://sketchfab.com/models/850342b563e44e1eb9413b347701a423/embed?autospin=0.2&amp;camera=0" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
<p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
</div>

Some tweezers we used for holding down electronic components:

<div class="sketchfab-embed-wrapper">
<iframe title="A 3D model" width="600" height="450" src="https://sketchfab.com/models/85e7031fa9fa444eabe54ac6152ed525/embed?autospin=0.2&amp;camera=0" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
<p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
</div>

I wondered if it was easier to use the tweezers with a reversed action, where applying force releases the object. And by default it holds the object. For this, I used this [mechanism designed by Devin Montes](<https://www.myminifactory.com/users/MakeAnything/collection/compliant-mechanisms>) \- [video](<https://www.youtube.com/watch?v=PgDJlLqeTdo>) and transformed it for the tweezers.

<div class="sketchfab-embed-wrapper">
<iframe title="A 3D model" width="600" height="450" src="https://sketchfab.com/models/43feaabeb46647b8a4778c10bea22740/embed?autospin=0.2&amp;camera=0" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
<p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
</div>

4. Creating toolpaths
---
I used Cura to make toolpaths for my 3d prints. I uploaded my stl files, set my machine, choose PLA as my material and used these settings:

![null](<./images/3dpd/cura.jpg>)

5. Printing
---
I used an [Anycubic Kossel Plus 3D printer](<https://www.anycubic.com/products/anycubic-kossel-3d-printer>) to print with a black 1.75mm PLA filament.

![null](<../images/3dpd/anycubic.jpg>)

Printing the gemclip: The finish was alright, as the first layer spread a little too much, causing it to be broader then the actual form. The first layer has a layer height of 0.3mm, and all the consecutive ones were 0.15mm. I used a cutting blade to finish these edges.  

![null](<./images/3dpd/gem3d.jpg>)

![null](<./images/3dpd/gemedge.jpg>)

In the next print, I used the same layer height for all layers. I printed a simple pick and place plier using a bent compliant joint.  

![null](<../images/3dpd/simpleplier.gif>)

Simple nose-end tweezers:

![null](<./images/3dpd/simpletweezers.jpg>)

Used the transformed chopstick geometry, modified it for the tweezers:

![null](<./images/3dpd/comptweezers.jpg>)

The bending details were too small, they broke while I was trying to clean them up.

![null](<./images/3dpd/brokentweezers.jpg>)

Overall, I made some small experiments with simple tools. I hope to remake the tweezer with the semi-compliant mechanism again after modifying the design.

![null](<./images/3dpd/lot.jpg>)

If I can have more time on the machines I can modify the mechanisms by trying out various different tollerences, size and setting. And maybe make a small set of complaint mechanism tools.

6. References  

[Design for 3d printing tutorials](<https://www.3dhubs.com/knowledge-base/>)

Here are some notes on principles of additive manufacturing.  
![](./images/3dpd/principles.jpg)  

7. Photogrammetry

I used Agisoft Metashape to make a pointcloud. I followed this [tutorial by Agisoft](<https://agisoft.freshdesk.com/support/solutions/articles/31000152092-3d-model-reconstruction>).

I clicked 53 images of the object on a plain background from all around. Steps to make a pointcloud:

1. Workflow > Add photos
2. Workflow > Align Photos (this step take some time depending on the number of key point limit and tie point limit you set.)
3. Some photos failed to align, but I got 9003 points
4. Workflow > Build dense cloud - medium quality.
5. Workflow > Build Mesh
6. Workflow > Build textures

The process: ![metashape](<./images/3dpd/agisoft.gif>)

The output:

<div class="sketchfab-embed-wrapper">
<iframe title="A 3D model" width="600" height="450" src="https://sketchfab.com/models/a3fdb19895234d9f9834fb48305ed7a4/embed?autospin=0.2&amp;camera=0" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
<p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
</div>

8. 3D Scanning

I used a Roland Modela MDX-20 to scan the same object. I used the [step-by-step manual](<http://fab.academany.org/2018/labs/barcelona/students/jeanbaptiste-natali/download/scanning_with_mdx-20_step_by_step.pdf>) for this.  
![nutbolt](<./images/3dpd/nutbolt.jpg>)

Stuck the bolt and nut using a double sided tape on the raised level bed.  
![setup](<../images/3dpd/setup.jpg>) I set the scanning area, as close to the object as possible. And a scanning grid of 0.5mm on both X and Y axes.

The output:

![output](<./images/3dpd/output.jpg>)

<div class="sketchfab-embed-wrapper">
<iframe title="A 3D model" width="600" height="450" src="https://sketchfab.com/models/c7382a9ac481437c8df7386913506f23/embed?autospin=0.2&amp;camera=0" frameborder="0" allow="autoplay; fullscreen; vr" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe><p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;">
</div>

9. Design files

[All 3D models for printing](<./images/3dpd/clampsandclips.3dm.zip>)  
[Probe scan of a lump of clay](<./images/3dpd/clay.probe.scan.stl.zip>)  
[Photogammetry of nut and bolt](<./images/3dpd/photogrammetry.obj.zip>)  
[Probe scan of nut and bolt](<./images/3dpd/probescan.zip>)  
[These transformed chopsticks](<./images/3dpd/reference.file.zip>)  
